@@ -44,19 +44,20 @@
   (defvar doric-earth-palette
     '((cursor "#770000")
       (bg-main "#f0eddf")
-      (fg-main "#1b0d10")
+      (fg-main "#30232e")
       (border "#a29986")
 
-      (bg-shadow-subtle "#dfd8c8")
-      (fg-shadow-subtle "#605040")
+      (bg-shadow-subtle "#dfdfce")
+      (fg-shadow-subtle "#635650")
 
-      (bg-neutral "#d2cabd")
+      (bg-neutral "#d1ceb6")
+      (fg-neutral "#604d48")
 
       (bg-shadow-intense "#c09fa0")
-      (fg-shadow-intense "#461327")
+      (fg-shadow-intense "#58383f")
 
-      (bg-accent "#dfc8ab")
-      (fg-accent "#783002")
+      (bg-accent "#e7d5b9")
+      (fg-accent "#74321f")
 
       (fg-faint-red "#750000")
       (fg-faint-green "#056100")
