@@ -45,18 +45,19 @@
     '((cursor "#eeddbb")
       (bg-main "#181818")
       (fg-main "#e7e7e7")
-      (border "#7e7e7e")
+      (border "#727272")
 
       (bg-shadow-subtle "#2f2f2f")
-      (fg-shadow-subtle "#8d8d8d")
+      (fg-shadow-subtle "#969696")
 
-      (bg-neutral "#454545")
+      (bg-neutral "#3a3a3a")
+      (fg-neutral "#a6a6a6")
 
       (bg-shadow-intense "#505050")
-      (fg-shadow-intense "#b4b4b4")
+      (fg-shadow-intense "#b0b0b0")
 
-      (bg-accent "#4a2b29")
-      (fg-accent "#be7f6b")
+      (bg-accent "#432f2a")
+      (fg-accent "#b59487")
 
       (fg-faint-red "#dba2a2")
       (fg-faint-green "#85c397")
