@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/doric-themes
-;; Version: 0.0.1
+;; Version: 0.1.0
 ;; Package-Requires: ((emacs "29.1"))
 ;; Keywords: faces, theme, accessibility
 
@@ -49,8 +49,8 @@
 (defconst doric-themes-dark-themes
   '(doric-dark
     doric-fire
-    doric-plum
     doric-obsidian
+    doric-plum
     doric-water)
   "Dark themes.")
 
@@ -75,7 +75,7 @@ themes that form part of this collection."
                          (list 'const theme))
                        doric-themes-collection)))
           `(choice
-            (const :tag "No toggle (default)" nil)
+            (const :tag "No toggle" nil)
             (list :tag "Pick two themes to toggle between"
                   (choice :tag "Theme one of two" ,@themes)
                   (choice :tag "Theme two of two" ,@themes))))
@@ -90,6 +90,19 @@ themes that form part of this collection."
   :package-version '(doric-themes . "0.1.0")
   :group 'doric-themes)
 
+(defvaralias 'doric-themes-post-load-hook 'doric-themes-after-load-theme-hook
+  "Alias for `doric-themes-after-load-theme-hook'.")
+
+(defcustom doric-themes-after-load-theme-hook nil
+  "Hook that runs after loading a Doric theme.
+This is used by the commands `doric-themes-toggle',
+`doric-themes-rotate', `doric-themes-load-random',
+`doric-themes-select', as well as the function
+`doric-themes-load-theme'."
+  :type 'hook
+  :package-version '(doric-themes . "0.1.0")
+  :group 'doric-themes)
+
 ;;;; Commands and their helper functions
 
 (defun doric-themes--doric-p (theme)
@@ -147,17 +160,18 @@ With optional PROMPT string, use it.  Else use a generic prompt."
       nil t nil 'doric-themes-select-theme-history))))
 
 (defun doric-themes-load-theme (theme)
-  "Load THEME while disabling other themes.
-Return THEME."
+  "Load THEME while disabling other themes and return THEME."
   (mapc #'disable-theme custom-enabled-themes)
   (load-theme theme :no-confirm)
+  (run-hooks 'doric-themes-after-load-theme-hook)
   theme)
 
 ;;;###autoload
 (defun doric-themes-select (theme)
   "Load a Doric THEME using minibuffer completion.
-Run `doric-themes-after-load-theme-hook' after loading the theme.
-Disable other themes per `doric-themes-disable-other-themes'."
+Disable other themes per `doric-themes-disable-other-themes'.
+
+Run `doric-themes-after-load-theme-hook' after loading the theme."
   (interactive (list (doric-themes-select-prompt)))
   (doric-themes-load-theme theme))
 
@@ -177,7 +191,9 @@ Disable other themes per `doric-themes-disable-other-themes'."
 If `doric-themes-to-toggle' does not specify two Doric themes, inform
 the user about it while prompting with completion for a theme among our
 collection (this is practically the same as the `doric-themes-select'
-command)."
+command).
+
+Run `doric-themes-after-load-theme-hook' after loading the theme."
   (interactive)
   (if (doric-themes--toggle-theme-p)
       (pcase-let ((`(,one ,two) doric-themes-to-toggle))
@@ -212,7 +228,9 @@ When called interactively THEMES is the value of `doric-themes-to-rotate'.
 
 If the current theme is already the next in line, then move to the one
 after.  Perform the rotation rightwards, such that the first element in
-the list becomes the last.  Do not modify THEMES in the process."
+the list becomes the last.  Do not modify THEMES in the process.
+
+Run `doric-themes-after-load-theme-hook' after loading a theme."
   (interactive (list doric-themes-to-rotate))
   (unless (proper-list-p themes)
     "This is not a list of themes: `%s'" themes)
@@ -260,7 +278,9 @@ respectively."
 
 With optional VARIANT as a prefix argument, prompt to limit the set of
 themes to either dark or light variants.  When called from Lisp, VARIANT
-is either the `dark' or `light' symbol."
+is either the `dark' or `light' symbol.
+
+Run `doric-themes-after-load-theme-hook' after loading a theme."
   (interactive
    (list
     (when current-prefix-arg
@@ -273,8 +293,12 @@ is either the `dark' or `light' symbol."
 ;;;; Face customisations
 
 (defconst doric-themes-selection-faces
-  '(calendar-today
-    company-tooltip-selection
+  '(avy-goto-char-timer-face
+    avy-lead-face
+    avy-lead-face-0
+    avy-lead-face-1
+    avy-lead-face-2
+    calendar-today
     completions-highlight
     consult-highlight-mark
     consult-highlight-match
@@ -307,6 +331,7 @@ is either the `dark' or `light' symbol."
 (defconst doric-themes-intense-shadow-faces
   '(blink-matching-paren-offscreen
     company-template-field
+    company-tooltip-selection
     company-tooltip-scrollbar-thumb
     corfu-current
     custom-button
@@ -373,11 +398,8 @@ is either the `dark' or `light' symbol."
     eww-form-textarea
     eww-form-text
     header-line
-    header-line-active
-    header-line-inactive
     magit-blame-heading
     magit-blame-margin
-    markdown-blockquote-face
     match
     menu
     mu4e-region-code
@@ -574,8 +596,6 @@ is either the `dark' or `light' symbol."
     org-scheduled-previously
     org-scheduled-today
     org-special-keyword
-    org-table-header
-    org-table-row
     org-time-grid
     org-upcoming-deadline
     org-upcoming-distant-deadline
@@ -630,6 +650,8 @@ is either the `dark' or `light' symbol."
     notmuch-search-flagged-face
     org-imminent-deadline
     org-headline-todo
+    org-table-header
+    org-table-row
     org-todo
     org-warning
     package-status-installed
@@ -679,7 +701,6 @@ is either the `dark' or `light' symbol."
     font-lock-negation-char-face
     font-lock-number-face
     font-lock-punctuation-face
-    fringe
     gnus-header-content
     gnus-server-opened
     gnus-summary-high-undownloaded
@@ -745,7 +766,6 @@ is either the `dark' or `light' symbol."
     org-archived
     org-default
     org-document-info
-    org-ellipsis
     org-inline-src-block
     org-latex-and-related
     org-mode-line-clock
@@ -1091,6 +1111,7 @@ is either the `dark' or `light' symbol."
     magit-signature-revoked
     magit-signature-untrusted
     magit-mode-line-process-error
+    markdown-blockquote-face
     markdown-inline-code-face
     message-cited-text-1
     message-cited-text-2
@@ -1120,8 +1141,6 @@ is either the `dark' or `light' symbol."
     tab-line-tab-special
     transient-key-noop
     vc-dir-status-edited
-    vc-edited-state
-    vc-locally-added-state
     vc-git-log-edit-summary-max-warning
     vc-git-log-edit-summary-target-warning
     which-key-docstring-face
@@ -1130,12 +1149,7 @@ is either the `dark' or `light' symbol."
     ztreep-node-count-children-face))
 
 (defconst doric-themes-underline-emphasis-faces
-  '(avy-goto-char-timer-face
-    avy-lead-face
-    avy-lead-face-0
-    avy-lead-face-1
-    avy-lead-face-2
-    aw-leading-char-face
+  '(aw-leading-char-face
     company-echo-common
     company-preview-common
     company-preview-search
@@ -1269,6 +1283,7 @@ is either the `dark' or `light' symbol."
            (custom-theme-set-faces
             ',name
             `(default ((t :background ,bg-main :foreground ,fg-main)))
+            `(fringe ((t :background unspecified :foreground ,fg-accent)))
             `(cursor ((t :background ,cursor)))
 
             '(bold ((t :weight bold)))
@@ -1417,8 +1432,8 @@ is either the `dark' or `light' symbol."
             `(magit-section-highlight (( )))
 
             `(markdown-code-face ((t :inherit fixed-pitch :background ,bg-shadow-subtle :extend t)))
-            '(markdown-language-keyword-face ((t :inherit fixed-pitch)))
-            '(markdown-table-face ((t :inherit fixed-pitch)))
+            `(markdown-language-keyword-face ((t :inherit fixed-pitch :background ,bg-neutral :foreground ,fg-neutral)))
+            `(markdown-table-face ((t :inherit fixed-pitch :foreground ,fg-accent)))
 
             '(markup-meta-face ((t :inherit fixed-pitch)))
             '(markup-replacement-face ((t :inherit fixed-pitch)))
@@ -1426,8 +1441,8 @@ is either the `dark' or `light' symbol."
             `(mode-line
               ((default :background ,bg-shadow-intense :foreground ,fg-shadow-intense)
                (((supports :box t))
-                :box ,fg-shadow-subtle)
-               (t :underline ,fg-shadow-subtle)))
+                :box ,border)
+               (t :underline ,border)))
 
             `(mode-line-active ((t :inherit mode-line)))
             `(mode-line-inactive
@@ -1442,7 +1457,7 @@ is either the `dark' or `light' symbol."
                  :overline ,fg-shadow-subtle)))
 
             `(org-block ((t :inherit fixed-pitch :background ,bg-shadow-subtle :extend t)))
-            `(org-block-begin-line ((t :inherit fixed-pitch :background ,bg-shadow-subtle :foreground ,fg-shadow-intense :extend t)))
+            `(org-block-begin-line ((t :inherit fixed-pitch :background ,bg-neutral :foreground ,fg-neutral :extend t)))
             `(org-block-end-line ((t :inherit org-block-begin-line)))
             '(org-checkbox ((t :inherit fixed-pitch)))
             `(org-column-title ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
@@ -1452,12 +1467,13 @@ is either the `dark' or `light' symbol."
                 :box (:line-width (-1 . -1) :color ,fg-accent))))
             `(org-document-info-keyword ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
             `(org-drawer ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
+            `(org-ellipsis (( ))) ; inherits from the heading's color
             '(org-formula ((t :inherit fixed-pitch)))
             `(org-hide ((t :foreground ,bg-main)))
             `(org-indent ((t :inherit (fixed-pitch org-hide))))
             `(org-meta-line ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
             '(org-property-value ((t :inherit fixed-pitch)))
-            `(org-table ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
+            `(org-table ((t :inherit fixed-pitch :foreground ,fg-accent)))
 
             `(reb-match-0 ((t :background ,bg-accent :foreground ,fg-main)))
             `(reb-match-1 ((t :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
@@ -1468,16 +1484,19 @@ is either the `dark' or `light' symbol."
             `(spacious-padding-subtle-mode-line-inactive ((t :foreground ,bg-accent)))
 
             `(tab-bar-tab ((t :inherit bold :background ,bg-main :foreground ,fg-main)))
-            `(tab-bar-tab-inactive ((t :background ,bg-neutral :foreground ,fg-shadow-subtle)))
+            `(tab-bar-tab-inactive ((t :background ,bg-neutral :foreground ,fg-neutral)))
 
             `(tab-line-tab ((t :inherit tab-line-tab-current)))
             `(tab-line-tab-current ((t :inherit bold :background ,bg-main :foreground ,fg-main)))
-            `(tab-line-tab-inactive ((t :background ,bg-neutral :foreground ,fg-shadow-subtle)))
+            `(tab-line-tab-inactive ((t :background ,bg-neutral :foreground ,fg-neutral)))
             `(tab-line-tab-inactive-alternate ((t :inherit tab-line-tab-inactive)))
 
             '(telega-webpage-fixed ((t :inherit fixed-pitch)))
             '(telega-webpage-preformatted ((t :inherit fixed-pitch)))
 
+            `(vc-edited-state ((t :inherit italic)))
+            `(vc-locally-added-state ((t :inherit italic)))
+
             '(vtable ((t :inherit fixed-pitch)))
 
             `(whitespace-big-indent ((t :foreground ,bg-shadow-intense)))
